## Precision
precision_tree = '//opgg-static.akamaized.net/images/lol/perkStyle/8000.png?image=q_auto:best&v=1607480996'
fleet = '//opgg-static.akamaized.net/images/lol/perk/8021.png?image=q_auto:best&v=1607480996'
conqueror = '//opgg-static.akamaized.net/images/lol/perk/8010.png?image=q_auto:best&v=1607480996'
pta = '//opgg-static.akamaized.net/images/lol/perk/8005.png?image=q_auto:best&v=1607480996'
lethal_tempo = '//opgg-static.akamaized.net/images/lol/perk/8008.png?image=q_auto:best&v=1607480996'
overheal = '//opgg-static.akamaized.net/images/lol/perk/9101.png?image=q_auto:best&v=1607480996'
triumph = '//opgg-static.akamaized.net/images/lol/perk/9111.png?image=q_auto:best&v=1607480996'
pom = '//opgg-static.akamaized.net/images/lol/perk/8009.png?image=q_auto:best&v=1607480996'
alacrity = '//opgg-static.akamaized.net/images/lol/perk/9104.png?image=q_auto:best&v=1607480996'
tenacity = '//opgg-static.akamaized.net/images/lol/perk/9105.png?image=q_auto:best&v=1607480996'
bloodline = '//opgg-static.akamaized.net/images/lol/perk/9103.png?image=q_auto:best&v=1607480996'
coup = '//opgg-static.akamaized.net/images/lol/perk/8014.png?image=q_auto:best&v=1607480996'
cut_down = '//opgg-static.akamaized.net/images/lol/perk/8017.png?image=q_auto:best&v=1607480996'
last_stand = '//opgg-static.akamaized.net/images/lol/perk/8299.png?image=q_auto:best&v=1607480996'

## Domination
domination_tree = '//opgg-static.akamaized.net/images/lol/perkStyle/8100.png?image=q_auto:best&v=1607480996'
hob = '//opgg-static.akamaized.net/images/lol/perk/9923.png?image=q_auto:best&v=1607480996'
electrocute = '//opgg-static.akamaized.net/images/lol/perk/8112.png?image=q_auto:best&v=1607480996'
predator = '//opgg-static.akamaized.net/images/lol/perk/8124.png?image=,q_auto:best&v=1607480996'
dh = '//opgg-static.akamaized.net/images/lol/perk/8128.png?image=q_auto:best&v=1607480996'
cheapshot = '//opgg-static.akamaized.net/images/lol/perk/8126.png?image=q_auto:best&v=1607480996'
tob = '//opgg-static.akamaized.net/images/lol/perk/8139.png?image=q_auto:best&v=1607480996'
sudden_impact = '//opgg-static.akamaized.net/images/lol/perk/8143.png?image=q_auto:best&v=1607480996'
zombie_ward = '//opgg-static.akamaized.net/images/lol/perk/8136.png?image=q_auto:best&v=1607480996'
ghost_poro = '//opgg-static.akamaized.net/images/lol/perk/8120.png?image=q_auto:best&v=1607480996'
eyeball = '//opgg-static.akamaized.net/images/lol/perk/8138.png?image=q_auto:best&v=1607480996'
ravenous = '//opgg-static.akamaized.net/images/lol/perk/8135.png?image=q_auto:best&v=1607480996'
ingenious = '//opgg-static.akamaized.net/images/lol/perk/8134.png?image=q_auto:best&v=1607480996'
relentless = '//opgg-static.akamaized.net/images/lol/perk/8105.png?image=q_auto:best&v=1607480996'
ultimate = '//opgg-static.akamaized.net/images/lol/perk/8106.png?image=q_auto:best&v=1607480996'

## Sorcery
sorcery_tree = '//opgg-static.akamaized.net/images/lol/perkStyle/8200.png?image=q_auto:best&v=1607480996'
comet = '//opgg-static.akamaized.net/images/lol/perk/8229.png?image=q_auto:best&v=1607480996'
aery = '//opgg-static.akamaized.net/images/lol/perk/8214.png?image=q_auto:best&v=1607480996'
phase_rush = '//opgg-static.akamaized.net/images/lol/perk/8230.png?image=q_auto:best&v=1607480996'
orb = '//opgg-static.akamaized.net/images/lol/perk/8224.png?image=q_auto:best&v=1607480996'
manaflow = '//opgg-static.akamaized.net/images/lol/perk/8226.png?image=q_auto:best&v=1607480996'
nimbus = '//opgg-static.akamaized.net/images/lol/perk/8275.png?image=q_auto:best&v=1607480996'
transcendence = '//opgg-static.akamaized.net/images/lol/perk/8210.png?image=q_auto:best&v=1607480996'
celarity = '//opgg-static.akamaized.net/images/lol/perk/8234.png?image=q_auto:best&v=1607480996'
focus = '//opgg-static.akamaized.net/images/lol/perk/8233.png?image=q_auto:best&v=1607480996'
scorch = '//opgg-static.akamaized.net/images/lol/perk/8237.png?image=q_auto:best&v=1607480996'
water_walking = '//opgg-static.akamaized.net/images/lol/perk/8232.png?image=q_auto:best&v=1607480996'
gathering_storm = '//opgg-static.akamaized.net/images/lol/perk/8236.png?image=q_auto:best&v=1607480996'

## Resolve
resolve_tree = '//opgg-static.akamaized.net/images/lol/perkStyle/8400.png?image=q_auto:best&v=1607480996'
grasp = '//opgg-static.akamaized.net/images/lol/perk/8437.png?image=q_auto:best&v=1607480996'
aftershock = '//opgg-static.akamaized.net/images/lol/perk/8439.png?image=q_auto:best&v=1607480996'
guardian = '//opgg-static.akamaized.net/images/lol/perk/8465.png?image=q_auto:best&v=1607480996'
demolish = '//opgg-static.akamaized.net/images/lol/perk/8446.png?image=q_auto:best&v=1607480996'
font_of_life = '//opgg-static.akamaized.net/images/lol/perk/8463.png?image=q_auto:best&v=1607480996'
shield_bash = '//opgg-static.akamaized.net/images/lol/perk/8401.png?image=q_auto:best&v=1607480996'
conditioning = '//opgg-static.akamaized.net/images/lol/perk/8429.png?image=q_auto:best&v=1607480996'
second_wind = '//opgg-static.akamaized.net/images/lol/perk/8444.png?image=q_auto:best&v=1607480996'
boneplating = '//opgg-static.akamaized.net/images/lol/perk/8473.png?image=q_auto:best&v=1607480996'
overgrowth = '//opgg-static.akamaized.net/images/lol/perk/8451.png?image=q_auto:best&v=1607480996'
revitalize = '//opgg-static.akamaized.net/images/lol/perk/8453.png?image=q_auto:best&v=1607480996'
unflinching = '//opgg-static.akamaized.net/images/lol/perk/8242.png?image=q_auto:best&v=1607480996'

## Inspiration
inspiration_tree = '//opgg-static.akamaized.net/images/lol/perkStyle/8300.png?image=q_auto:best&v=1607480996'
glacial = '//opgg-static.akamaized.net/images/lol/perk/8351.png?image=q_auto:best&v=1607480996'
spellbook = '//opgg-static.akamaized.net/images/lol/perk/8360.png?image=q_auto:best&v=1607480996'
omnistone = '//opgg-static.akamaized.net/images/lol/perk/8358.png?image=q_auto:best&v=1607480996'
hexflash = '//opgg-static.akamaized.net/images/lol/perk/8306.png?image=q_auto:best&v=1607480996'
footwear = '//opgg-static.akamaized.net/images/lol/perk/8304.png?image=q_auto:best&v=1607480996'
stopwatch = '//opgg-static.akamaized.net/images/lol/perk/8313.png?image=q_auto:best&v=1607480996'
future = '//opgg-static.akamaized.net/images/lol/perk/8321.png?image=q_auto:best&v=1607480996'
minion = '//opgg-static.akamaized.net/images/lol/perk/8316.png?image=q_auto:best&v=1607480996'
biscuit = '//opgg-static.akamaized.net/images/lol/perk/8345.png?image=q_auto:best&v=1607480996'
cosmic = '//opgg-static.akamaized.net/images/lol/perk/8347.png?image=q_auto:best&v=1607480996'
approach_velocity = '//opgg-static.akamaized.net/images/lol/perk/8410.png?image=q_auto:best&v=1607480996'
timewarp = '//opgg-static.akamaized.net/images/lol/perk/8352.png?image=q_auto:best&v=1607480996'



primary_rune_tree_img = {
    'precision': '//opgg-static.akamaized.net/images/lol/perkStyle/8000.png?image=q_auto:best&v=1607480996',
    'domination': '//opgg-static.akamaized.net/images/lol/perkStyle/8100.png?image=q_auto:best&v=1607480996',
    'sorcery': '//opgg-static.akamaized.net/images/lol/perkStyle/8200.png?image=q_auto:best&v=1607480996',
    'resolve': '//opgg-static.akamaized.net/images/lol/perkStyle/8400.png?image=q_auto:best&v=1607480996',
    'inspiration': '//opgg-static.akamaized.net/images/lol/perkStyle/8300.png?image=q_auto:best&v=1607480996'
}

keystones_img = {
    'fleet': '//opgg-static.akamaized.net/images/lol/perk/8021.png?image=q_auto:best&v=1607480996',
    'conqueror': '//opgg-static.akamaized.net/images/lol/perk/8010.png?image=q_auto:best&v=1607480996',
    'pta': '//opgg-static.akamaized.net/images/lol/perk/8005.png?image=q_auto:best&v=1607480996',
    'lethal_tempo': '//opgg-static.akamaized.net/images/lol/perk/8008.png?image=q_auto:best&v=1607480996',
    'hob': '//opgg-static.akamaized.net/images/lol/perk/9923.png?image=q_auto:best&v=1607480996',
    'electrocute': '//opgg-static.akamaized.net/images/lol/perk/8112.png?image=q_auto:best&v=1607480996',
    'predator': '//opgg-static.akamaized.net/images/lol/perk/8124.png?image=,q_auto:best&v=1607480996',
    'dh': '//opgg-static.akamaized.net/images/lol/perk/8128.png?image=q_auto:best&v=1607480996',
    'comet': '//opgg-static.akamaized.net/images/lol/perk/8229.png?image=q_auto:best&v=1607480996',
    'aery': '//opgg-static.akamaized.net/images/lol/perk/8214.png?image=q_auto:best&v=1607480996',
    'phase_rush': '//opgg-static.akamaized.net/images/lol/perk/8230.png?image=q_auto:best&v=1607480996',
    'grasp': '//opgg-static.akamaized.net/images/lol/perk/8437.png?image=q_auto:best&v=1607480996',
    'aftershock': '//opgg-static.akamaized.net/images/lol/perk/8439.png?image=q_auto:best&v=1607480996',
    'guardian': '//opgg-static.akamaized.net/images/lol/perk/8465.png?image=q_auto:best&v=1607480996',
    'glacial': '//opgg-static.akamaized.net/images/lol/perk/8351.png?image=q_auto:best&v=1607480996',
    'spellbook': '//opgg-static.akamaized.net/images/lol/perk/8360.png?image=q_auto:best&v=1607480996',
    'omnistone': '//opgg-static.akamaized.net/images/lol/perk/8358.png?image=q_auto:best&v=1607480996'
}

rune1_img = {
    'overheal': '//opgg-static.akamaized.net/images/lol/perk/9101.png?image=q_auto:best&v=1607480996',
    'triumph': '//opgg-static.akamaized.net/images/lol/perk/9111.png?image=q_auto:best&v=1607480996',
    'pom': '//opgg-static.akamaized.net/images/lol/perk/8009.png?image=q_auto:best&v=1607480996',
    'cheapshot': '//opgg-static.akamaized.net/images/lol/perk/8126.png?image=q_auto:best&v=1607480996',
    'tob': '//opgg-static.akamaized.net/images/lol/perk/8139.png?image=q_auto:best&v=1607480996',
    'sudden_impact': '//opgg-static.akamaized.net/images/lol/perk/8143.png?image=q_auto:best&v=1607480996',
    'orb': '//opgg-static.akamaized.net/images/lol/perk/8224.png?image=q_auto:best&v=1607480996',
    'manaflow': '//opgg-static.akamaized.net/images/lol/perk/8226.png?image=q_auto:best&v=1607480996',
    'nimbus': '//opgg-static.akamaized.net/images/lol/perk/8275.png?image=q_auto:best&v=1607480996',
    'demolish': '//opgg-static.akamaized.net/images/lol/perk/8446.png?image=q_auto:best&v=1607480996',
    'font_of_life': '//opgg-static.akamaized.net/images/lol/perk/8463.png?image=q_auto:best&v=1607480996',
    'shield_bash': '//opgg-static.akamaized.net/images/lol/perk/8401.png?image=q_auto:best&v=1607480996',
    'hexflash': '//opgg-static.akamaized.net/images/lol/perk/8306.png?image=q_auto:best&v=1607480996',
    'footwear': '//opgg-static.akamaized.net/images/lol/perk/8304.png?image=q_auto:best&v=1607480996',
    'stopwatch': '//opgg-static.akamaized.net/images/lol/perk/8313.png?image=q_auto:best&v=1607480996'
}

rune2_img = {
    'alacrity': '//opgg-static.akamaized.net/images/lol/perk/9104.png?image=q_auto:best&v=1607480996',
    'tenacity': '//opgg-static.akamaized.net/images/lol/perk/9105.png?image=q_auto:best&v=1607480996',
    'bloodline': '//opgg-static.akamaized.net/images/lol/perk/9103.png?image=q_auto:best&v=1607480996',
    'zombie_ward': '//opgg-static.akamaized.net/images/lol/perk/8136.png?image=q_auto:best&v=1607480996',
    'ghost_poro': '//opgg-static.akamaized.net/images/lol/perk/8120.png?image=q_auto:best&v=1607480996',
    'eyeball': '//opgg-static.akamaized.net/images/lol/perk/8138.png?image=q_auto:best&v=1607480996',
    'transcendence': '//opgg-static.akamaized.net/images/lol/perk/8210.png?image=q_auto:best&v=1607480996',
    'celarity': '//opgg-static.akamaized.net/images/lol/perk/8234.png?image=q_auto:best&v=1607480996',
    'focus': '//opgg-static.akamaized.net/images/lol/perk/8233.png?image=q_auto:best&v=1607480996',
    'conditioning': '//opgg-static.akamaized.net/images/lol/perk/8429.png?image=q_auto:best&v=1607480996',
    'second_wind': '//opgg-static.akamaized.net/images/lol/perk/8444.png?image=q_auto:best&v=1607480996',
    'boneplating': '//opgg-static.akamaized.net/images/lol/perk/8473.png?image=q_auto:best&v=1607480996',
    'future': '//opgg-static.akamaized.net/images/lol/perk/8321.png?image=q_auto:best&v=1607480996',
    'minion': '//opgg-static.akamaized.net/images/lol/perk/8316.png?image=q_auto:best&v=1607480996',
    'biscuit': '//opgg-static.akamaized.net/images/lol/perk/8345.png?image=q_auto:best&v=1607480996'
}

rune3_img = {
    'coup': '//opgg-static.akamaized.net/images/lol/perk/8014.png?image=q_auto:best&v=1607480996',
    'cut_down': '//opgg-static.akamaized.net/images/lol/perk/8017.png?image=q_auto:best&v=1607480996',
    'last_stand': '//opgg-static.akamaized.net/images/lol/perk/8299.png?image=q_auto:best&v=1607480996',
    'ravenous': '//opgg-static.akamaized.net/images/lol/perk/8135.png?image=q_auto:best&v=1607480996',
    'ingenious': '//opgg-static.akamaized.net/images/lol/perk/8134.png?image=q_auto:best&v=1607480996',
    'relentless': '//opgg-static.akamaized.net/images/lol/perk/8105.png?image=q_auto:best&v=1607480996',
    'ultimate': '//opgg-static.akamaized.net/images/lol/perk/8106.png?image=q_auto:best&v=1607480996',
    'scorch': '//opgg-static.akamaized.net/images/lol/perk/8237.png?image=q_auto:best&v=1607480996',
    'water_walking': '//opgg-static.akamaized.net/images/lol/perk/8232.png?image=q_auto:best&v=1607480996',
    'gathering_storm': '//opgg-static.akamaized.net/images/lol/perk/8236.png?image=q_auto:best&v=1607480996',
    'overgrowth': '//opgg-static.akamaized.net/images/lol/perk/8451.png?image=q_auto:best&v=1607480996',
    'revitalize': '//opgg-static.akamaized.net/images/lol/perk/8453.png?image=q_auto:best&v=1607480996',
    'unflinching': '//opgg-static.akamaized.net/images/lol/perk/8242.png?image=q_auto:best&v=1607480996',
    'cosmic': '//opgg-static.akamaized.net/images/lol/perk/8347.png?image=q_auto:best&v=1607480996',
    'approach_velocity': '//opgg-static.akamaized.net/images/lol/perk/8410.png?image=q_auto:best&v=1607480996',
    'timewarp': '//opgg-static.akamaized.net/images/lol/perk/8352.png?image=q_auto:best&v=1607480996'
}

######################################################
primary_rune_tree_emoji = {
    '<:precision:792162680369971261>': '//opgg-static.akamaized.net/images/lol/perkStyle/8000.png?image=q_auto:best&v=1607480996',
    '<:domination:792414255214493716>': '//opgg-static.akamaized.net/images/lol/perkStyle/8100.png?image=q_auto:best&v=1607480996',
    '<:sorcery:792441210152288256>': '//opgg-static.akamaized.net/images/lol/perkStyle/8200.png?image=q_auto:best&v=1607480996',
    '<:resolve:792421207949312020>': '//opgg-static.akamaized.net/images/lol/perkStyle/8400.png?image=q_auto:best&v=1607480996',
    '<:inspiration:792420733887709224>': '//opgg-static.akamaized.net/images/lol/perkStyle/8300.png?image=q_auto:best&v=1607480996'
}

keystones_emoji = {
    '<:FleetFootwork:792169831943503923>': '//opgg-static.akamaized.net/images/lol/perk/8021.png?image=q_auto:best&v=1607480996',
    '<:Conqueror:792169654340419654>': '//opgg-static.akamaized.net/images/lol/perk/8010.png?image=q_auto:best&v=1607480996',
    '<:pta:792175571857571841>': '//opgg-static.akamaized.net/images/lol/perk/8005.png?image=q_auto:best&v=1607480996',
    '<:lt:792413035187798047>': '//opgg-static.akamaized.net/images/lol/perk/8008.png?image=q_auto:best&v=1607480996',
    '<:hob:792415338142367774>': '//opgg-static.akamaized.net/images/lol/perk/9923.png?image=q_auto:best&v=1607480996',
    '<:electrocute:792415844625547305>': '//opgg-static.akamaized.net/images/lol/perk/8112.png?image=q_auto:best&v=1607480996',
    '<:predator:792417169086218280>': '//opgg-static.akamaized.net/images/lol/perk/8124.png?image=,q_auto:best&v=1607480996',
    '<:dh:792417673408413728>': '//opgg-static.akamaized.net/images/lol/perk/8128.png?image=q_auto:best&v=1607480996',
    '<:aery:792419580969746482>': '//opgg-static.akamaized.net/images/lol/perk/8229.png?image=q_auto:best&v=1607480996',
    '<:comet1:792419590751256597>': '//opgg-static.akamaized.net/images/lol/perk/8214.png?image=q_auto:best&v=1607480996',
    '<:phaserush:792419599215624243>': '//opgg-static.akamaized.net/images/lol/perk/8230.png?image=q_auto:best&v=1607480996',
    '<:grasp:792422018187264020>': '//opgg-static.akamaized.net/images/lol/perk/8437.png?image=q_auto:best&v=1607480996',
    '<:aftershock:792422039952556062>': '//opgg-static.akamaized.net/images/lol/perk/8439.png?image=q_auto:best&v=1607480996',
    '<:guardian:792422039411490858>': '//opgg-static.akamaized.net/images/lol/perk/8465.png?image=q_auto:best&v=1607480996',
    '<:glacial:792423350667706368>': '//opgg-static.akamaized.net/images/lol/perk/8351.png?image=q_auto:best&v=1607480996',
    '<:spellbook:792423350956982302>': '//opgg-static.akamaized.net/images/lol/perk/8360.png?image=q_auto:best&v=1607480996',
    '<:omnistone:792423350609510449>': '//opgg-static.akamaized.net/images/lol/perk/8358.png?image=q_auto:best&v=1607480996'
}

rune1_emoji = {
    '<:overheal:792426715120140288>': '//opgg-static.akamaized.net/images/lol/perk/9101.png?image=q_auto:best&v=1607480996',
    '<:triumph1:792426714973208597>': '//opgg-static.akamaized.net/images/lol/perk/9111.png?image=q_auto:best&v=1607480996',
    '<:pom:792426715217002526>': '//opgg-static.akamaized.net/images/lol/perk/8009.png?image=q_auto:best&v=1607480996',
    '<:cheapshot:792442972620455947>': '//opgg-static.akamaized.net/images/lol/perk/8126.png?image=q_auto:best&v=1607480996',
    '<:tob:792442972855074826>': '//opgg-static.akamaized.net/images/lol/perk/8139.png?image=q_auto:best&v=1607480996',
    '<:suddenimpact:792442972875653140>': '//opgg-static.akamaized.net/images/lol/perk/8143.png?image=q_auto:best&v=1607480996',
    '<:orb:792454318623555594>': '//opgg-static.akamaized.net/images/lol/perk/8224.png?image=q_auto:best&v=1607480996',
    '<:manaflow:792454318032420874>': '//opgg-static.akamaized.net/images/lol/perk/8226.png?image=q_auto:best&v=1607480996',
    '<:nimbus:792454318191149136>': '//opgg-static.akamaized.net/images/lol/perk/8275.png?image=q_auto:best&v=1607480996',
    '<:demolish:792457268523696128>': '//opgg-static.akamaized.net/images/lol/perk/8446.png?image=q_auto:best&v=1607480996',
    '<:fontoflife:792457268100202527>': '//opgg-static.akamaized.net/images/lol/perk/8463.png?image=q_auto:best&v=1607480996',
    '<:shieldbash:792457268637204490>': '//opgg-static.akamaized.net/images/lol/perk/8401.png?image=q_auto:best&v=1607480996',
    '<:hexflash:792458707744980993>': '//opgg-static.akamaized.net/images/lol/perk/8306.png?image=q_auto:best&v=1607480996',
    '<:footwear:792458707794788372>': '//opgg-static.akamaized.net/images/lol/perk/8304.png?image=q_auto:best&v=1607480996',
    '<:stopwatch1:792458707509968936>': '//opgg-static.akamaized.net/images/lol/perk/8313.png?image=q_auto:best&v=1607480996'
}

rune2_emoji = {
    '<:alacrity:792429210035159073>': '//opgg-static.akamaized.net/images/lol/perk/9104.png?image=q_auto:best&v=1607480996',
    '<:tenacity:792429212383969311>': '//opgg-static.akamaized.net/images/lol/perk/9105.png?image=q_auto:best&v=1607480996',
    '<:bloodline:792429210865631262>': '//opgg-static.akamaized.net/images/lol/perk/9103.png?image=q_auto:best&v=1607480996',
    '<:zombieward:792456100011573278>': '//opgg-static.akamaized.net/images/lol/perk/8136.png?image=q_auto:best&v=1607480996',
    '<:ghostporo:792456099886399488>': '//opgg-static.akamaized.net/images/lol/perk/8120.png?image=q_auto:best&v=1607480996',
    '<:eyeball:792456099709452338>': '//opgg-static.akamaized.net/images/lol/perk/8138.png?image=q_auto:best&v=1607480996',
    '<:transcendence:792454318422753311>': '//opgg-static.akamaized.net/images/lol/perk/8210.png?image=q_auto:best&v=1607480996',
    '<:celarity:792454317877493810>': '//opgg-static.akamaized.net/images/lol/perk/8234.png?image=q_auto:best&v=1607480996',
    '<:focus:792454317571440662>': '//opgg-static.akamaized.net/images/lol/perk/8233.png?image=q_auto:best&v=1607480996',
    '<:conditioning:792457267990495304>': '//opgg-static.akamaized.net/images/lol/perk/8429.png?image=q_auto:best&v=1607480996',
    '<:secondwind:792457268624490556>': '//opgg-static.akamaized.net/images/lol/perk/8444.png?image=q_auto:best&v=1607480996',
    '<:boneplating:792457267932692511>': '//opgg-static.akamaized.net/images/lol/perk/8473.png?image=q_auto:best&v=1607480996',
    '<:future:792458707467894794>': '//opgg-static.akamaized.net/images/lol/perk/8321.png?image=q_auto:best&v=1607480996',
    '<:minion:792458707295535136>': '//opgg-static.akamaized.net/images/lol/perk/8316.png?image=q_auto:best&v=1607480996',
    '<:biscuit:792458706511069254>': '//opgg-static.akamaized.net/images/lol/perk/8345.png?image=q_auto:best&v=1607480996'
}

rune3_emoji = {
    '<:coup:792430510512406619>': '//opgg-static.akamaized.net/images/lol/perk/8014.png?image=q_auto:best&v=1607480996',
    '<:cutdown:792430510806007838>': '//opgg-static.akamaized.net/images/lol/perk/8017.png?image=q_auto:best&v=1607480996',
    '<:laststand:792430510390509570>': '//opgg-static.akamaized.net/images/lol/perk/8299.png?image=q_auto:best&v=1607480996',
    '<:ravenous:792455662692073472>': '//opgg-static.akamaized.net/images/lol/perk/8135.png?image=q_auto:best&v=1607480996',
    '<:ingenious:792455662604648448>': '//opgg-static.akamaized.net/images/lol/perk/8134.png?image=q_auto:best&v=1607480996',
    '<:relentless:792455662595866654>': '//opgg-static.akamaized.net/images/lol/perk/8105.png?image=q_auto:best&v=1607480996',
    '<:ultimate:792455662659567647>': '//opgg-static.akamaized.net/images/lol/perk/8106.png?image=q_auto:best&v=1607480996',
    '<:scorch:792454318317633586>': '//opgg-static.akamaized.net/images/lol/perk/8237.png?image=q_auto:best&v=1607480996',
    '<:waterwalking:792454318028619814>': '//opgg-static.akamaized.net/images/lol/perk/8232.png?image=q_auto:best&v=1607480996',
    '<:gatheringstorm:792454317915373568>': '//opgg-static.akamaized.net/images/lol/perk/8236.png?image=q_auto:best&v=1607480996',
    '<:overgrowth:792457268293664779>': '//opgg-static.akamaized.net/images/lol/perk/8451.png?image=q_auto:best&v=1607480996',
    '<:revitalize:792457268507312148>': '//opgg-static.akamaized.net/images/lol/perk/8453.png?image=q_auto:best&v=1607480996',
    '<:unflinching:792457268499054631>': '//opgg-static.akamaized.net/images/lol/perk/8242.png?image=q_auto:best&v=1607480996',
    '<:cosmic:792458706646073384>': '//opgg-static.akamaized.net/images/lol/perk/8347.png?image=q_auto:best&v=1607480996',
    '<:approachvelocity:792458706468995103>': '//opgg-static.akamaized.net/images/lol/perk/8410.png?image=q_auto:best&v=1607480996',
    '<:timewarp:792458707023691776>': '//opgg-static.akamaized.net/images/lol/perk/8352.png?image=q_auto:best&v=1607480996'
}

######################################################
tree_names = {
    'Precision': '//opgg-static.akamaized.net/images/lol/perkStyle/8000.png?image=q_auto:best&v=1607480996',
    'Domination': '//opgg-static.akamaized.net/images/lol/perkStyle/8100.png?image=q_auto:best&v=1607480996',
    'Sorcery': '//opgg-static.akamaized.net/images/lol/perkStyle/8200.png?image=q_auto:best&v=1607480996',
    'Resolve': '//opgg-static.akamaized.net/images/lol/perkStyle/8400.png?image=q_auto:best&v=1607480996',
    'Inspiration': '//opgg-static.akamaized.net/images/lol/perkStyle/8300.png?image=q_auto:best&v=1607480996'
}

keystone_names = {
    'Fleet Footwork': '//opgg-static.akamaized.net/images/lol/perk/8021.png?image=q_auto:best&v=1607480996',
    'Conqueror': '//opgg-static.akamaized.net/images/lol/perk/8010.png?image=q_auto:best&v=1607480996',
    'Press the Attack': '//opgg-static.akamaized.net/images/lol/perk/8005.png?image=q_auto:best&v=1607480996',
    'Lethal Tempo': '//opgg-static.akamaized.net/images/lol/perk/8008.png?image=q_auto:best&v=1607480996',
    'Hail of Blades': '//opgg-static.akamaized.net/images/lol/perk/9923.png?image=q_auto:best&v=1607480996',
    'Electrocute': '//opgg-static.akamaized.net/images/lol/perk/8112.png?image=q_auto:best&v=1607480996',
    'Predator': '//opgg-static.akamaized.net/images/lol/perk/8124.png?image=,q_auto:best&v=1607480996',
    'Dark Harvest': '//opgg-static.akamaized.net/images/lol/perk/8128.png?image=q_auto:best&v=1607480996',
    'Arcane Comet': '//opgg-static.akamaized.net/images/lol/perk/8229.png?image=q_auto:best&v=1607480996',
    'Summon Aery': '//opgg-static.akamaized.net/images/lol/perk/8214.png?image=q_auto:best&v=1607480996',
    'Phase Rush': '//opgg-static.akamaized.net/images/lol/perk/8230.png?image=q_auto:best&v=1607480996',
    'Grasp of the Undying': '//opgg-static.akamaized.net/images/lol/perk/8437.png?image=q_auto:best&v=1607480996',
    'Aftershock': '//opgg-static.akamaized.net/images/lol/perk/8439.png?image=q_auto:best&v=1607480996',
    'Guardian': '//opgg-static.akamaized.net/images/lol/perk/8465.png?image=q_auto:best&v=1607480996',
    'Glacial Augment': '//opgg-static.akamaized.net/images/lol/perk/8351.png?image=q_auto:best&v=1607480996',
    'Unsealed Spellbook': '//opgg-static.akamaized.net/images/lol/perk/8360.png?image=q_auto:best&v=1607480996',
    'Prototype: Omnistone': '//opgg-static.akamaized.net/images/lol/perk/8358.png?image=q_auto:best&v=1607480996'
}

rune1_names = {
    'Overheal': '//opgg-static.akamaized.net/images/lol/perk/9101.png?image=q_auto:best&v=1607480996',
    'Triumph': '//opgg-static.akamaized.net/images/lol/perk/9111.png?image=q_auto:best&v=1607480996',
    'Presence of Mind': '//opgg-static.akamaized.net/images/lol/perk/8009.png?image=q_auto:best&v=1607480996',
    'Cheap Shot': '//opgg-static.akamaized.net/images/lol/perk/8126.png?image=q_auto:best&v=1607480996',
    'Taste of Blood': '//opgg-static.akamaized.net/images/lol/perk/8139.png?image=q_auto:best&v=1607480996',
    'Sudden Impact': '//opgg-static.akamaized.net/images/lol/perk/8143.png?image=q_auto:best&v=1607480996',
    'Nullifying Orb': '//opgg-static.akamaized.net/images/lol/perk/8224.png?image=q_auto:best&v=1607480996',
    'Manaflow Band': '//opgg-static.akamaized.net/images/lol/perk/8226.png?image=q_auto:best&v=1607480996',
    'Nimbus Cloak': '//opgg-static.akamaized.net/images/lol/perk/8275.png?image=q_auto:best&v=1607480996',
    'Demolish': '//opgg-static.akamaized.net/images/lol/perk/8446.png?image=q_auto:best&v=1607480996',
    'Font of Life': '//opgg-static.akamaized.net/images/lol/perk/8463.png?image=q_auto:best&v=1607480996',
    'Shield Bash': '//opgg-static.akamaized.net/images/lol/perk/8401.png?image=q_auto:best&v=1607480996',
    'Hexflash Flashtraption': '//opgg-static.akamaized.net/images/lol/perk/8306.png?image=q_auto:best&v=1607480996',
    'Magical Footwear': '//opgg-static.akamaized.net/images/lol/perk/8304.png?image=q_auto:best&v=1607480996',
    'Perfect Timing': '//opgg-static.akamaized.net/images/lol/perk/8313.png?image=q_auto:best&v=1607480996'
}

rune2_names = {
    'Legend: Alacrity': '//opgg-static.akamaized.net/images/lol/perk/9104.png?image=q_auto:best&v=1607480996',
    'Legend: Tenacity': '//opgg-static.akamaized.net/images/lol/perk/9105.png?image=q_auto:best&v=1607480996',
    'Legend: Bloodline': '//opgg-static.akamaized.net/images/lol/perk/9103.png?image=q_auto:best&v=1607480996',
    'Zombie Ward': '//opgg-static.akamaized.net/images/lol/perk/8136.png?image=q_auto:best&v=1607480996',
    'Ghost Poro': '//opgg-static.akamaized.net/images/lol/perk/8120.png?image=q_auto:best&v=1607480996',
    'Eyeball Collection': '//opgg-static.akamaized.net/images/lol/perk/8138.png?image=q_auto:best&v=1607480996',
    'Transcendence': '//opgg-static.akamaized.net/images/lol/perk/8210.png?image=q_auto:best&v=1607480996',
    'Celarity': '//opgg-static.akamaized.net/images/lol/perk/8234.png?image=q_auto:best&v=1607480996',
    'Absolute Focus': '//opgg-static.akamaized.net/images/lol/perk/8233.png?image=q_auto:best&v=1607480996',
    'Conditioning': '//opgg-static.akamaized.net/images/lol/perk/8429.png?image=q_auto:best&v=1607480996',
    'Second Wind': '//opgg-static.akamaized.net/images/lol/perk/8444.png?image=q_auto:best&v=1607480996',
    'Bone Plating': '//opgg-static.akamaized.net/images/lol/perk/8473.png?image=q_auto:best&v=1607480996',
    "Future's Market": '//opgg-static.akamaized.net/images/lol/perk/8321.png?image=q_auto:best&v=1607480996',
    'Minion Dematerializer': '//opgg-static.akamaized.net/images/lol/perk/8316.png?image=q_auto:best&v=1607480996',
    'Biscuit Delivery': '//opgg-static.akamaized.net/images/lol/perk/8345.png?image=q_auto:best&v=1607480996'
}

rune3_names = {
    'Coup de Grace': '//opgg-static.akamaized.net/images/lol/perk/8014.png?image=q_auto:best&v=1607480996',
    'Cut Down': '//opgg-static.akamaized.net/images/lol/perk/8017.png?image=q_auto:best&v=1607480996',
    'Last Stand': '//opgg-static.akamaized.net/images/lol/perk/8299.png?image=q_auto:best&v=1607480996',
    'Ravenous Hunter': '//opgg-static.akamaized.net/images/lol/perk/8135.png?image=q_auto:best&v=1607480996',
    'Ingenious Hunter': '//opgg-static.akamaized.net/images/lol/perk/8134.png?image=q_auto:best&v=1607480996',
    'Relentless Hunter': '//opgg-static.akamaized.net/images/lol/perk/8105.png?image=q_auto:best&v=1607480996',
    'Ultimate Hunter': '//opgg-static.akamaized.net/images/lol/perk/8106.png?image=q_auto:best&v=1607480996',
    'Scorch': '//opgg-static.akamaized.net/images/lol/perk/8237.png?image=q_auto:best&v=1607480996',
    'Waterwalking': '//opgg-static.akamaized.net/images/lol/perk/8232.png?image=q_auto:best&v=1607480996',
    'Gathering Storm': '//opgg-static.akamaized.net/images/lol/perk/8236.png?image=q_auto:best&v=1607480996',
    'Overgrowth': '//opgg-static.akamaized.net/images/lol/perk/8451.png?image=q_auto:best&v=1607480996',
    'Revitalize': '//opgg-static.akamaized.net/images/lol/perk/8453.png?image=q_auto:best&v=1607480996',
    'Unflinching': '//opgg-static.akamaized.net/images/lol/perk/8242.png?image=q_auto:best&v=1607480996',
    'Cosmic Insight': '//opgg-static.akamaized.net/images/lol/perk/8347.png?image=q_auto:best&v=1607480996',
    'Approach Velocity': '//opgg-static.akamaized.net/images/lol/perk/8410.png?image=q_auto:best&v=1607480996',
    'Time Warp Tonic': '//opgg-static.akamaized.net/images/lol/perk/8352.png?image=q_auto:best&v=1607480996'
}



IRON_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377379497869353/Emblem_Iron.png"
SILVER_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791376720967368724/Emblem_Silver.png"
BRONZE_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377369566281748/Emblem_Bronze.png"
GOLD_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377378962047036/Emblem_Gold.png"
PLATINUM_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377382132547584/Emblem_Platinum.png"
DIAMOND_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377375622725652/Emblem_Diamond.png"
MASTER_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377381713248317/Emblem_Master.png"
GRANDMASTER_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377379607445564/Emblem_Grandmaster.png"
CHALLENGER_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377373044015154/Emblem_Challenger.png"

AATROX_PROFILE_URL = "http://ddragon.leagueoflegends.com/cdn/10.25.1/img/champion/Aatrox.png"


import requests
import bs4
from Bot.runes import *


url = 'https://na.op.gg/champion/nasus/statistics'

response = requests.get(url)

soup = bs4.BeautifulSoup(response.text, 'lxml')

rune_tree = soup.find_all('div', {'class': 'perk-page__row'})[0].find('img').attrs['src']
keystone = soup.find_all('div', {'class': 'perk-page__item--active'})[0].find('img').attrs['src']
rune1 = soup.find_all('div', {'class': 'perk-page__item--active'})[1].find('img').attrs['src']
secondary = soup.find_all('div', {'class': 'perk-page__item--active'})[5].find('img').attrs['src']
rune_tree_2 = soup.find_all('div', {'class': 'perk-page__item--mark'})[1].find('img').attrs['src']
win_rate = soup.find_all('div', {'class': 'champion-stats-trend-rate'})[0].text

for runes in primary_rune_tree_img:
    if rune_tree == primary_rune_tree_img[runes]:
        for tree in tree_names:
            if rune_tree == tree_names[tree]:
                for emoji in primary_rune_tree_emoji:
                    if rune_tree == primary_rune_tree_emoji[emoji]:
                        rune_tree = emoji
                        tree_name = tree
                        break

print(rune_tree, tree_name)


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

discordpy = 'discord.py'
riotwatcher = 'riotwatcher'
bs4 = 'bs4'
lxml = 'lxml'

setuptools.setup(
    name="scuttlebot", # Replace with your own username
    version="0.0.1",
    author="Noah Garrett",
    author_email="nwggaming123@gmail.com",
    description="LoL Discord Bot",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://discord.gg/VMwphqfmQk",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[discordpy, riotwatcher, bs4, lxml]
)


import discord
from discord.ext import commands, tasks
from discord.utils import get
import asyncio
from riotwatcher import LolWatcher, ApiError
import os, json

API_KEY = 'RGAPI-75074842-5be7-4b9a-904e-548c8b3b34df'
REGION = 'na1'
LOL_WATCHER = LolWatcher(API_KEY)

client = commands.Bot(command_prefix= '#')
token = 'NzkxMzM2MTk0MjMwODQ1NDkw.X-NrQw.tOvPuEh5k6mW6ltEgTsiBPaOhvA'

## Cog Setup ##
for filename in os.listdir('./cogs'):
    if filename.endswith('.py'):
        client.load_extension(f'cogs.{filename[:-3]}')
        print(f'Loaded: {filename[:-3]}')

## Helper Functions ##
async def get_summoner_id(summoner):
    sum_id = LOL_WATCHER.summoner.by_name(REGION, summoner)
    return sum_id

async def get_rank(summoner):
    sum_id = await get_summoner_id(summoner)
    sum_rank = LOL_WATCHER.league.by_summoner(REGION, sum_id['id'])
    return sum_rank

async def get_champ_list():
    versions = LOL_WATCHER.data_dragon.versions_for_region(REGION)
    champ_version = versions['n']['champion']
    current_champ_list = LOL_WATCHER.data_dragon.champions(champ_version)
    return current_champ_list


## Runs Bot ##
client.run(token)